summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/propertyeditor.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit32b67ac0690de411b26b1d5e715b188c27442248 (patch)
tree43167816a3df6b3a877d71c9a7963ed270dcc8c9 /kdevdesigner/designer/propertyeditor.cpp
parent330c33ab6f97b279737bf9527c9add7bb1475450 (diff)
downloadtdevelop-32b67ac0690de411b26b1d5e715b188c27442248.tar.gz
tdevelop-32b67ac0690de411b26b1d5e715b188c27442248.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdevdesigner/designer/propertyeditor.cpp')
-rw-r--r--kdevdesigner/designer/propertyeditor.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/kdevdesigner/designer/propertyeditor.cpp b/kdevdesigner/designer/propertyeditor.cpp
index 6535ef7f..402c1117 100644
--- a/kdevdesigner/designer/propertyeditor.cpp
+++ b/kdevdesigner/designer/propertyeditor.cpp
@@ -167,7 +167,7 @@ bool PropertyWhatsThis::clicked( const TQString& href )
*/
/*! If this item should be a child of another property item, specify
- \a prop as the tqparent item.
+ \a prop as the parent item.
*/
PropertyItem::PropertyItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName )
@@ -308,7 +308,7 @@ bool PropertyItem::hasSubItems() const
return FALSE;
}
/*! Returns the tqparent property item here if this is a child or 0
otherwise.
*/
@@ -2592,8 +2592,8 @@ void PropertyKeysequenceItem::setValue( const TQVariant &v )
// --------------------------------------------------------------
-EnumPopup::EnumPopup( TQWidget *tqparent, const char *name, WFlags f )
- : TQFrame( tqparent, name, f )
+EnumPopup::EnumPopup( TQWidget *parent, const char *name, WFlags f )
+ : TQFrame( parent, name, f )
{
setLineWidth( 1 );
setFrameStyle( Panel | Plain );
@@ -2654,8 +2654,8 @@ TQValueList<EnumItem> EnumPopup::enumList() const
return itemList;
}
-EnumBox::EnumBox( TQWidget *tqparent, const char *name )
- : TQComboBox( tqparent, name )
+EnumBox::EnumBox( TQWidget *parent, const char *name )
+ : TQComboBox( parent, name )
{
pop = new EnumPopup( this, "popup", TQObject::WType_Popup );
connect( pop, TQT_SIGNAL( hidden() ), this, TQT_SLOT( popupHidden() ) );
@@ -2730,7 +2730,7 @@ void EnumBox::popup()
popupShown = FALSE;
return;
}
- pop->move( ((TQWidget*)tqparent())->mapToGlobal( tqgeometry().bottomLeft() ) );
+ pop->move( ((TQWidget*)parent())->mapToGlobal( tqgeometry().bottomLeft() ) );
pop->setMinimumWidth( width() );
emit aboutToShowPopup();
pop->show();
@@ -3153,8 +3153,8 @@ void PropertyList::setupProperties()
continue;
if ( qstrcmp( p->name(), "buttonGroupId" ) == 0 ) { // #### remove this when designable in TQ_PROPERTY can take a function (isInButtonGroup() in this case)
if ( !editor->widget()->isWidgetType() ||
- !editor->widget()->tqparent() ||
- !::tqqt_cast<TQButtonGroup*>(editor->widget()->tqparent()) )
+ !editor->widget()->parent() ||
+ !::tqqt_cast<TQButtonGroup*>(editor->widget()->parent()) )
continue;
}
@@ -3916,8 +3916,8 @@ PropertyList::LastEventType PropertyList::lastEvent()
}
// ------------------------------------------------------------
-EventList::EventList( TQWidget *tqparent, FormWindow *fw, PropertyEditor *e )
- : HierarchyList( tqparent, fw, TRUE ), editor( e )
+EventList::EventList( TQWidget *parent, FormWindow *fw, PropertyEditor *e )
+ : HierarchyList( parent, fw, TRUE ), editor( e )
{
header()->hide();
removeColumn( 1 );
@@ -3991,7 +3991,7 @@ extern TQListViewItem *newItem;
void EventList::contentsMouseDoubleClickEvent( TQMouseEvent *e )
{
TQListViewItem *i = itemAt( contentsToViewport( e->pos() ) );
- if ( !i || i->tqparent() )
+ if ( !i || i->parent() )
return;
TQString s;
if ( !formWindow->project()->isCpp() ) {
@@ -4014,7 +4014,7 @@ void EventList::setCurrent( TQWidget * )
void EventList::objectClicked( TQListViewItem *i )
{
- if ( !i || !i->tqparent() )
+ if ( !i || !i->parent() )
return;
// formWindow->clearSelection(false);
formWindow->mainWindow()->part()->emitEditFunction(formWindow->fileName(), i->text( 0 ));
@@ -4034,20 +4034,20 @@ void EventList::showRMBMenu( TQListViewItem *i, const TQPoint &pos )
if ( res == NEW_ITEM ) {
TQString s;
if ( !formWindow->project()->isCpp() ) {
- TQString s1 = ( i->tqparent() ? i->tqparent() : i )->text( 0 );
+ TQString s1 = ( i->parent() ? i->parent() : i )->text( 0 );
int pt = s1.find( "(" );
if ( pt != -1 )
s1 = s1.left( pt );
s = TQString( editor->widget()->name() ) + "_" + s1;
} else {
- s = TQString( editor->widget()->name() ) + "_" + ( i->tqparent() ? i->tqparent() : i )->text( 0 );
+ s = TQString( editor->widget()->name() ) + "_" + ( i->parent() ? i->parent() : i )->text( 0 );
}
- insertEntry( i->tqparent() ? i->tqparent() : i, SmallIcon( "designer_editslots.png" , KDevDesignerPartFactory::instance()), s );
- } else if ( res == DEL_ITEM && i->tqparent() ) {
+ insertEntry( i->parent() ? i->parent() : i, SmallIcon( "designer_editslots.png" , KDevDesignerPartFactory::instance()), s );
+ } else if ( res == DEL_ITEM && i->parent() ) {
MetaDataBase::Connection conn;
conn.sender = editor->widget();
conn.receiver = TQT_TQOBJECT(formWindow->mainContainer());
- conn.signal = i->tqparent()->text( 0 );
+ conn.signal = i->parent()->text( 0 );
conn.slot = i->text( 0 );
delete i;
RemoveConnectionCommand *cmd = new RemoveConnectionCommand( i18n( "Remove Connection" ),
@@ -4063,9 +4063,9 @@ void EventList::renamed( TQListViewItem *i )
{
if ( newItem == i )
newItem = 0;
- if ( !i->tqparent() )
+ if ( !i->parent() )
return;
- TQListViewItem *itm = i->tqparent()->firstChild();
+ TQListViewItem *itm = i->parent()->firstChild();
bool del = FALSE;
while ( itm ) {
if ( itm != i && itm->text( 0 ) == i->text( 0 ) ) {
@@ -4081,7 +4081,7 @@ void EventList::renamed( TQListViewItem *i )
MetaDataBase::Connection conn;
conn.sender = editor->widget();
conn.receiver = TQT_TQOBJECT(formWindow->mainContainer());
- conn.signal = i->tqparent()->text( 0 );
+ conn.signal = i->parent()->text( 0 );
conn.slot = i->text( 0 );
AddConnectionCommand *cmd = new AddConnectionCommand( i18n( "Add Connection" ),
formWindow,
@@ -4091,7 +4091,7 @@ void EventList::renamed( TQListViewItem *i )
// exists and if we can connect to this one
TQString funcname = i->text( 0 ).latin1();
if ( funcname.find( '(' ) == -1 ) { // try to create a signature
- TQString sig = i->tqparent()->text( 0 );
+ TQString sig = i->parent()->text( 0 );
sig = sig.mid( sig.find( '(' ) + 1 );
sig.remove( (int)sig.length() - 1, 1 );
LanguageInterface *iface = MetaDataBase::languageInterface( formWindow->project()->language() );
@@ -4138,8 +4138,8 @@ void EventList::save( TQListViewItem *p )
listview for editing properties.
*/
-PropertyEditor::PropertyEditor( TQWidget *tqparent )
- : TQTabWidget( tqparent, 0, WStyle_Customize | WStyle_NormalBorder | WStyle_Title |
+PropertyEditor::PropertyEditor( TQWidget *parent )
+ : TQTabWidget( parent, 0, WStyle_Customize | WStyle_NormalBorder | WStyle_Title |
WStyle_StaysOnTop | WStyle_Tool |WStyle_MinMax | WStyle_SysMenu )
{
setCaption( i18n( "Property Editor" ) );
@@ -308,7 +308,7 @@ bool PropertyItem::hasSubItems() const
return FALSE;
}
-/*! Returns the tqparent property item here if this is a child or 0
+/*! Returns the parent property item here if this is a child or 0
otherwise.
*/